@@ -239,9 +239,9 @@ class CloudFrontToMediaStoreProps:
         :summary: The properties for the CloudFrontToMediaStore Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(media_store_container_props, dict):
-            media_store_container_props = CfnContainerProps(**media_store_container_props)
+            media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
         if __debug__:
             type_hints = typing.get_type_hints(CloudFrontToMediaStoreProps.__init__)
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
